@@ -21,7 +21,8 @@ class FRAMEWORK:
     FURIOSA = "furiosa"
     MmDetection = "mmdetection"
     MmDetection_GPU = "mmdetection_gpu"
-    TF_RT = "tensort"
+    TensorRT = "TensorRT"
+    OTHER = "other"
 
 
 # =====================================================================================================================
@@ -69,7 +70,7 @@ class DEVICE:
         CPU = "CPU"
         CUDA = "CUDA"
 
-    class TF_RT:
+    class TensorRT:
         CPU = "CPU"
         CUDA = "CUDA"
 
@@ -89,7 +90,7 @@ SUPPORT_DEVICES = {
         FRAMEWORK.FURIOSA: [DEVICE.FURIOSA.CPU, DEVICE.FURIOSA.CUDA],
         FRAMEWORK.MmDetection: [DEVICE.MmDetection.CPU],
         FRAMEWORK.MmDetection_GPU: [DEVICE.MmDetection.CPU, DEVICE.MmDetection_GPU.CUDA],
-        FRAMEWORK.TF_RT: [DEVICE.TF_RT.CPU, DEVICE.TF_RT.CUDA]
+        FRAMEWORK.TensorRT: [DEVICE.TensorRT.CPU, DEVICE.TensorRT.CUDA]
     },
     ARCHITECTURE.AARCH64: {},
     ARCHITECTURE.ARMV7HF: {}
@@ -108,7 +109,7 @@ class MODEL_TYPE:
     TORCH = "TORCH"
     KERAS = "KERAS"
     CAFFE = "CAFFE"
-    TF_RT = "TF_RT"
+    TensorRT = "TensorRT"
 
 
 # =====================================================================================================================
