@@ -1,5 +1,5 @@
 
-class MODULE:
+class Module:
     """
         modules container mqtt and redis ports as individual
     """
